*From raw data to stata daset used in annual calculations for OECD countires Table 7 

clear all
set more off
pause off

cd "$main\data"
use Indicators_Ifscode.dta
keep ifscode lettercode
rename lettercode wdicode
sort ifscode
save ifs_wdi.dta, replace
local vars gdp ur emp /*lf*/ pop 
local vars2 /*ulc gdpdef */hw
foreach v of local vars{
clear all
insheet using `v'_updated.csv, comma
drop in 1/2
drop in 2/2
drop in 3/3
rename v1 period
quietly describe
local N `r(k)'
forval i = 2/`N' {
	local title = v`i' in 1
	local title2 = v`i' in 2/2
	preserve
	drop in 1
	drop in 1
	keep period v`i'
	gen country = "`title'&`title2'"
	split country, p("&", ".")
	
	rename v`i' `v'
	
	save temp`i'.dta, replace
	restore
}

clear
gen period = ""
forval i = 2/`N' {
	append using temp`i'.dta
	erase temp`i'.dta
}
destring period, replace
drop country
rename country1 country
rename country2 ifscode
replace ifscode=country3 if country3!="" & (country=="Korea" )
drop if country=="China"
drop country3 
drop country4

replace `v'="" if `v'=="n.a."
destring `v', replace ignore(e)
destring ifscode, replace
gen date=subinstr(period,"A1","",.)
destring date, replace
order date period ifscode country `v'
sort ifscode date
save `v'_updated.dta,replace
}

foreach v of local vars2{
clear all
insheet using `v'_updated.csv, comma
drop in 1/2
drop in 2/2
drop in 3/3
rename v1 period
quietly describe
local N `r(k)'
forval i = 2/`N' {
	local title = v`i' in 1
	local title2 = v`i' in 2/2
	preserve
	drop in 1
	drop in 1
	keep period v`i'
	gen country = "`title'&`title2'"
	split country, p("&", ".")
	
	rename v`i' `v'
	
	save temp`i'.dta, replace
	restore
}

clear
gen period = ""
forval i = 2/`N' {
	append using temp`i'.dta
	erase temp`i'.dta
}
destring period, replace
drop country
rename country1 country
rename country2 ifscode

replace `v'="" if `v'=="n.a."
destring `v', replace ignore(e)
destring ifscode, replace
gen date=subinstr(period,"A1","",.)
destring date, replace
order date period ifscode country `v'
sort ifscode date
save `v'_updated.dta,replace
}





clear all
use gdp_updated.dta
merge 1:1 ifscode date using ur_updated.dta
drop country5
drop country6
drop _merge
sort country date
merge 1:1 ifscode date using emp_updated.dta
drop _merge
sort country date
/*merge 1:1 ifscode date using lf.dta
drop _merge
sort country date*/
merge 1:1 ifscode date using pop_updated.dta
drop _merge
/*merge 1:1 ifscode date using ulc.dta
drop _merge
merge 1:1 ifscode date using gdpdef.dta
drop _merge*/
merge 1:1 ifscode date using hw_updated.dta
drop _merge

label var gdp "Gross domestic product, volume, market prices"
label var  ur  "Unemployment rate \ PER CENT"
label var  emp "Total employment \ PERSONS"
*label var lf  "Labour force \ PERSONS"
label var pop "Working-age population, age 15 and older \ PERSONS"
*label var ulc "Unit labour cost,  overall economy, index 2005=100 \ INDEX"
*label var gdpdef "Gross domestic product, deflator, market prices \ INDEX"
label var hw "Hours worked per employee, total economy \ HOURS"

sort ifscode
merge ifscode using ifs_wdi.dta
drop if date==.
drop _merge

drop country3
order date period ifscode wdicode country gdp ur emp /*lf*/
rename date year

tsset ifscode year
drop period


***************************************************************
* Merge in additional data
***************************************************************
sort ifscode year
merge ifscode year using oecd_a_weo.dta
drop _merge

***************************************************************
* Sample
***************************************************************

* 20 advanced economies (from NBER BLL paper)

local ifsc 193 122 124 156 128 172 132 134 178 136 158 138 196 142 182 184 144 146 112 111
gen ae20 = 0
foreach i of local ifsc{
replace ae20 = 1 if ifscode == `i'
}

keep if ae20==1
drop ae20

* Fill missing wdicodes and country names
sort ifscode year
bys ifscode: gen minus_year = -1*year

bys ifscode: replace wdicode = wdicode[_n-1] if year>=2014
sort minus_year
bys ifscode: replace wdicode = wdicode[_n-1] if year<1980
sort ifscode year

bys ifscode: replace country = country[_n-1] if year>=2014
sort minus_year
bys ifscode: replace country = country[_n-1] if year<1980
sort ifscode year

drop minus_year

* Years: start in 1979 to allow 1980 to be first observation for all countries

keep if year>=1979

***************************************************************
* Transform data
***************************************************************

* Log of real GDP
bys ifscode: gen logy =ln(gdp)
bys ifscode: replace logy= logy * 100
lab var logy "Log of GDP times 100" 

gen logy_weo =ln(gdp_weo)
replace logy_weo= logy_weo * 100


* Change in ln(GDP)
sort ifscode year
bys ifscode: gen y_chg = 100*(ln(gdp/gdp[_n-1]))
lab var y_chg "GDP growth"

* Change in U rate
bys ifscode: gen ur_chg = (ur-ur[_n-1])
lab var ur_chg "Change in unemployment rate"

* Log of employment
bys ifscode: gen ln_emp = ln(emp)
bys ifscode: replace ln_emp = ln_emp*100

bys ifscode: gen ln_emp_weo = ln(emp_weo)
bys ifscode: replace ln_emp_weo = ln_emp_weo*100

* Change in ln(employment)
bys ifscode: gen emp_chg1 = 100*(ln(emp/emp[_n-1]))
lab var emp_chg1 "Employment growth"



***************************************************************
* Splicing data for 2014-18 period using WEO October 2013. 
***************************************************************


lab var logy_weo "Log of GDP times 100. Spliced after 2013 using data from WEO (October 2013)" 

gen aux = logy
replace aux = aux[_n-1] + (logy_weo - logy_weo[_n-1]) if year >=2014

drop logy_weo
rename aux logy_weo
lab var logy_weo "Log of GDP times 100. Spliced after 2013 using data from WEO (October 2013)." 


gen aux = ur
replace aux = aux[_n-1] + (ur_weo - ur_weo[_n-1]) if year >=2014
drop ur_weo
rename aux ur_weo
lab var ur_weo "Unemployment rate. Spliced after 2013 using data from WEO (October 2013)."


gen aux = ln_emp
replace aux = aux[_n-1] + (ln_emp_weo - ln_emp_weo[_n-1]) if year >=2014
drop ln_emp_weo
rename aux ln_emp_weo
lab var ln_emp_weo "Log of employment times 100. Spliced after 2013 using data from WEO (October 2013)." 

***************************************************************
* HP Filtering (lambda = 1000)
***************************************************************

* HP Filtering
* Smoothing factor 1000: GDP
sort ifscode year
bys ifscode: hprescott logy, smooth(1000) stub(H1)
forval i = 1/20 {
	bys ifscode: replace H1_logy_sm_`i' = 0 if H1_logy_sm_`i'==.
}
gen logy_hpf1000 = H1_logy_sm_1
forval i = 2/20 {
	replace logy_hpf1000 = logy_hpf1000 + H1_logy_sm_`i'
}
drop *H1* 
bys ifscode: replace logy_hpf1000=. if logy_hpf1000 ==0
lab var logy_hpf1000 "GDP hp-filtered 1000 factor"

* HP Filtering
* Smoothing factor 1000: UR
sort ifscode year
bys ifscode: hprescott ur, smooth(1000) stub(H1)
forval i = 1/20 {
	bys ifscode: replace H1_ur_sm_`i' = 0 if H1_ur_sm_`i'==.
}
gen ur_hpf1000 = H1_ur_sm_1
forval i = 2/20 {
	replace ur_hpf1000 = ur_hpf1000 + H1_ur_sm_`i'
}
drop *H1* 
bys ifscode: replace ur_hpf1000=. if ur_hpf1000 ==0
rename ur_hpf1000 u_hpf1000
lab var u_hpf1000 "UR hp-filtered 1000 factor"

* HP Filtering
* Smoothing factor 1000: Employment
sort ifscode year
bys ifscode: hprescott ln_emp, smooth(1000) stub(H1)
forval i = 1/20 {
	bys ifscode: replace H1_ln_emp_sm_`i' = 0 if H1_ln_emp_sm_`i'==.
}
gen ln_emp_hpf1000 = H1_ln_emp_sm_1
forval i = 2/20 {
	replace ln_emp_hpf1000 = ln_emp_hpf1000 + H1_ln_emp_sm_`i'
}
drop *H1* 
bys ifscode: replace ln_emp_hpf1000=. if ln_emp_hpf1000 ==0
lab var ln_emp_hpf1000 "Log Employment hp-filtered 1000 factor"

***************************************************************
* HP Filtering (lambda = 100)
***************************************************************

* HP Filtering
* Smoothing factor 100: GDP
sort ifscode year
bys ifscode: hprescott logy, smooth(100) stub(H1)
forval i = 1/20 {
	bys ifscode: replace H1_logy_sm_`i' = 0 if H1_logy_sm_`i'==.
}
gen logy_hpf100 = H1_logy_sm_1
forval i = 2/20 {
	replace logy_hpf100 = logy_hpf100 + H1_logy_sm_`i'
}
drop *H1* 
bys ifscode: replace logy_hpf100=. if logy_hpf100 ==0
lab var logy_hpf100 "GDP hp-filtered 100 factor"

* HP Filtering
* Smoothing factor 100: UR
sort ifscode year
bys ifscode: hprescott ur, smooth(100) stub(H1)
forval i = 1/20 {
	bys ifscode: replace H1_ur_sm_`i' = 0 if H1_ur_sm_`i'==.
}
gen ur_hpf100 = H1_ur_sm_1
forval i = 2/20 {
	replace ur_hpf100 = ur_hpf100 + H1_ur_sm_`i'
}
drop *H1* 
bys ifscode: replace ur_hpf100=. if ur_hpf100 ==0
rename ur_hpf100 u_hpf100
lab var u_hpf100 "UR hp-filtered 100 factor"

* HP Filtering
* Smoothing factor 100: Employment
sort ifscode year
bys ifscode: hprescott ln_emp, smooth(100) stub(H1)
forval i = 1/20 {
	bys ifscode: replace H1_ln_emp_sm_`i' = 0 if H1_ln_emp_sm_`i'==.
}
gen ln_emp_hpf100 = H1_ln_emp_sm_1
forval i = 2/20 {
	replace ln_emp_hpf100 = ln_emp_hpf100 + H1_ln_emp_sm_`i'
}
drop *H1* 
bys ifscode: replace ln_emp_hpf100=. if ln_emp_hpf100 ==0
lab var ln_emp_hpf100 "Log Employment hp-filtered 100 factor"

***************************************************************
* HP Filtering and Gaps for Precrisis Sample (up to 2007) 
***************************************************************

bys ifscode: gen logy_2007 = logy if year < 2008
lab var logy_2007 "Log of GDP ending in 2007"

bys ifscode: gen u_2007    = ur    if year < 2008
lab var u_2007 "UR ending in 2007"

bys ifscode: gen emp_2007    = ln_emp    if year < 2008
lab var emp_2007 "Employment ending in 2007"

* lambda = 100

* HP Filtering
* Smoothing factor 100: GDP
sort ifscode year
bys ifscode: hprescott logy_2007, smooth(100) stub(H1)
forval i = 1/20 {
	bys ifscode: replace H1_logy_2007_sm_`i' = 0 if H1_logy_2007_sm_`i'==.
}
gen logy_2007_hpf100 = H1_logy_2007_sm_1
forval i = 2/20 {
	replace logy_2007_hpf100 = logy_2007_hpf100 + H1_logy_2007_sm_`i'
}
drop *H1* 
bys ifscode: replace logy_2007_hpf100=. if logy_2007_hpf100 ==0
rename logy_2007_hpf100 logy_hpf100_07
lab var logy_hpf100_07 "GDP hp-filtered 100 factor ending in 2007"
sort ifscode year
bys ifscode: gen ystar100 = logy_hpf100_07-logy_hpf100_07[_n-1] if year==2007
bys ifscode: replace ystar100 = ystar100[_n-1] if year>=2008
forvalue i=1/6{
	bys ifscode: replace logy_hpf100_07 = logy_hpf100_07[_n-1] + ystar100 if year==2007+`i'
	}
drop ystar100

* HP Filtering
* Smoothing factor 100: UR
sort ifscode year
bys ifscode: hprescott u_2007, smooth(100) stub(H1)
forval i = 1/20 {
	bys ifscode: replace H1_u_2007_sm_`i' = 0 if H1_u_2007_sm_`i'==.
}
gen u_2007_hpf100 = H1_u_2007_sm_1
forval i = 2/20 {
	replace u_2007_hpf100 = u_2007_hpf100 + H1_u_2007_sm_`i'
}
drop *H1* 
bys ifscode: replace u_2007_hpf100=. if u_2007_hpf100 ==0

rename u_2007_hpf100 u_hpf100_07
lab var u_hpf100_07 "UR hp-filtered 100 factor ending in 2007"
bys ifscode: gen ustar100 = u_hpf100_07 if year==2007
bys ifscode: replace ustar100 = ustar100[_n-1] if year>=2008
forvalue i=1/6{
	bys ifscode: replace u_hpf100_07 = ustar100 if year==2007+`i'
	}
drop ustar100

* HP Filtering
* Smoothing factor 100: emp
sort ifscode year
bys ifscode: hprescott emp_2007, smooth(100) stub(H1)
forval i = 1/20 {
	bys ifscode: replace H1_emp_2007_sm_`i' = 0 if H1_emp_2007_sm_`i'==.
}
gen emp_2007_hpf100 = H1_emp_2007_sm_1
forval i = 2/20 {
	replace emp_2007_hpf100 = emp_2007_hpf100 + H1_emp_2007_sm_`i'
}
drop *H1* 
bys ifscode: replace emp_2007_hpf100=. if emp_2007_hpf100 ==0
rename emp_2007_hpf100 ln_emp_hpf100_07
lab var ln_emp_hpf100_07 "emp hp-filtered 100 factor ending in 2007"
sort ifscode year
bys ifscode: gen empstar100 = ln_emp_hpf100_07-ln_emp_hpf100_07[_n-1] if year==2007
bys ifscode: replace empstar100 = empstar100[_n-1] if year>=2008
forvalue i=1/6{
	bys ifscode: replace ln_emp_hpf100_07 = ln_emp_hpf100_07[_n-1] + empstar100 if year==2007+`i'
	}
drop empstar100

***************************************************************

* lambda = 1000

* HP Filtering
* Smoothing factor 1000: GDP
sort ifscode year
bys ifscode: hprescott logy_2007, smooth(1000) stub(H1)
forval i = 1/20 {
	bys ifscode: replace H1_logy_2007_sm_`i' = 0 if H1_logy_2007_sm_`i'==.
}
gen logy_2007_hpf1000 = H1_logy_2007_sm_1
forval i = 2/20 {
	replace logy_2007_hpf1000 = logy_2007_hpf1000 + H1_logy_2007_sm_`i'
}
drop *H1* 
bys ifscode: replace logy_2007_hpf1000=. if logy_2007_hpf1000 ==0
rename logy_2007_hpf1000 logy_hpf1000_07
lab var logy_hpf1000_07 "GDP hp-filtered 1000 factor ending in 2007"
sort ifscode year
bys ifscode: gen ystar1000 = logy_hpf1000_07-logy_hpf1000_07[_n-1] if year==2007
bys ifscode: replace ystar1000 = ystar1000[_n-1] if year>=2008
forvalue i=1/6{
	bys ifscode: replace logy_hpf1000_07 = logy_hpf1000_07[_n-1] + ystar1000 if year==2007+`i'
	}
drop ystar1000

* HP Filtering
* Smoothing factor 1000: UR
sort ifscode year
bys ifscode: hprescott u_2007, smooth(1000) stub(H1)
forval i = 1/20 {
	bys ifscode: replace H1_u_2007_sm_`i' = 0 if H1_u_2007_sm_`i'==.
}
gen u_2007_hpf1000 = H1_u_2007_sm_1
forval i = 2/20 {
	replace u_2007_hpf1000 = u_2007_hpf1000 + H1_u_2007_sm_`i'
}
drop *H1* 
bys ifscode: replace u_2007_hpf1000=. if u_2007_hpf1000 ==0

rename u_2007_hpf1000 u_hpf1000_07
lab var u_hpf1000_07 "UR hp-filtered 1000 factor ending in 2007"
bys ifscode: gen ustar1000 = u_hpf1000_07 if year==2007
bys ifscode: replace ustar1000 = ustar1000[_n-1] if year>=2008
forvalue i=1/6{
	bys ifscode: replace u_hpf1000_07 = ustar1000 if year==2007+`i'
	}
drop ustar1000

* HP Filtering
* Smoothing factor 1000: emp
sort ifscode year
bys ifscode: hprescott emp_2007, smooth(1000) stub(H1)
forval i = 1/20 {
	bys ifscode: replace H1_emp_2007_sm_`i' = 0 if H1_emp_2007_sm_`i'==.
}
gen emp_2007_hpf1000 = H1_emp_2007_sm_1
forval i = 2/20 {
	replace emp_2007_hpf1000 = emp_2007_hpf1000 + H1_emp_2007_sm_`i'
}
drop *H1* 
bys ifscode: replace emp_2007_hpf1000=. if emp_2007_hpf1000 ==0
rename emp_2007_hpf1000 ln_emp_hpf1000_07
lab var ln_emp_hpf1000_07 "emp hp-filtered 1000 factor ending in 2007"
sort ifscode year
bys ifscode: gen empstar1000 = ln_emp_hpf1000_07-ln_emp_hpf1000_07[_n-1] if year==2007
bys ifscode: replace empstar1000 = empstar1000[_n-1] if year>=2008
forvalue i=1/6{
	bys ifscode: replace ln_emp_hpf1000_07 = ln_emp_hpf1000_07[_n-1] + empstar1000 if year==2007+`i'
	}
drop empstar1000

***************************************************************
* HP Filtering (lambda = 100).  WEO forecasts through 2018.
***************************************************************

* HP Filtering
* Smoothing factor 100: GDP
sort ifscode year
bys ifscode: hprescott logy_weo, smooth(100) stub(H1)
forval i = 1/20 {
	bys ifscode: replace H1_logy_weo_sm_`i' = 0 if H1_logy_weo_sm_`i'==.
}
gen logy_weo_hpf100 = H1_logy_weo_sm_1
forval i = 2/20 {
	replace logy_weo_hpf100 = logy_weo_hpf100 + H1_logy_weo_sm_`i'
}
drop *H1* 
bys ifscode: replace logy_weo_hpf100=. if logy_weo_hpf100 ==0
lab var logy_weo_hpf100 "GDP hp-filtered 100 factor. WEO forecasts through 2018."

* HP Filtering
* Smoothing factor 100: ur_weo
sort ifscode year
bys ifscode: hprescott ur_weo, smooth(100) stub(H1)
forval i = 1/20 {
	bys ifscode: replace H1_ur_weo_sm_`i' = 0 if H1_ur_weo_sm_`i'==.
}
gen ur_weo_hpf100 = H1_ur_weo_sm_1
forval i = 2/20 {
	replace ur_weo_hpf100 = ur_weo_hpf100 + H1_ur_weo_sm_`i'
}
drop *H1* 
bys ifscode: replace ur_weo_hpf100=. if ur_weo_hpf100 ==0
rename ur_weo_hpf100 u_weo_hpf100
lab var u_weo_hpf100 "UR hp-filtered 100 factor. WEO forecasts through 2018."

* HP Filtering
* Smoothing factor 100: ln(emp)
sort ifscode year
bys ifscode: hprescott ln_emp_weo, smooth(100) stub(H1)
forval i = 1/20 {
	bys ifscode: replace H1_ln_emp_weo_sm_`i' = 0 if H1_ln_emp_weo_sm_`i'==.
}
gen ln_emp_weo_hpf100 = H1_ln_emp_weo_sm_1
forval i = 2/20 {
	replace ln_emp_weo_hpf100 = ln_emp_weo_hpf100 + H1_ln_emp_weo_sm_`i'
}
drop *H1* 
bys ifscode: replace ln_emp_weo_hpf100=. if ln_emp_weo_hpf100 ==0
lab var ln_emp_weo_hpf100 "Log Employment hp-filtered 100 factor. WEO forecasts through 2018."

***************************************************************
* HP Filtering (lambda = 1000).  WEO forecasts through 2018.
***************************************************************

* HP Filtering
* Smoothing factor 1000: GDP
sort ifscode year
bys ifscode: hprescott logy_weo, smooth(1000) stub(H1)
forval i = 1/20 {
	bys ifscode: replace H1_logy_weo_sm_`i' = 0 if H1_logy_weo_sm_`i'==.
}
gen logy_weo_hpf1000 = H1_logy_weo_sm_1
forval i = 2/20 {
	replace logy_weo_hpf1000 = logy_weo_hpf1000 + H1_logy_weo_sm_`i'
}
drop *H1* 
bys ifscode: replace logy_weo_hpf1000=. if logy_weo_hpf1000 ==0
lab var logy_weo_hpf1000 "GDP hp-filtered 1000 factor. WEO forecasts through 2018."

* HP Filtering
* Smoothing factor 1000: ur_weo
sort ifscode year
bys ifscode: hprescott ur_weo, smooth(1000) stub(H1)
forval i = 1/20 {
	bys ifscode: replace H1_ur_weo_sm_`i' = 0 if H1_ur_weo_sm_`i'==.
}
gen ur_weo_hpf1000 = H1_ur_weo_sm_1
forval i = 2/20 {
	replace ur_weo_hpf1000 = ur_weo_hpf1000 + H1_ur_weo_sm_`i'
}
drop *H1* 
bys ifscode: replace ur_weo_hpf1000=. if ur_weo_hpf1000 ==0
rename ur_weo_hpf1000 u_weo_hpf1000
lab var u_weo_hpf1000 "UR hp-filtered 1000 factor. WEO forecasts through 2018."

* HP Filtering
* Smoothing factor 1000: ln(emp)
sort ifscode year
bys ifscode: hprescott ln_emp_weo, smooth(1000) stub(H1)
forval i = 1/20 {
	bys ifscode: replace H1_ln_emp_weo_sm_`i' = 0 if H1_ln_emp_weo_sm_`i'==.
}
gen ln_emp_weo_hpf1000 = H1_ln_emp_weo_sm_1
forval i = 2/20 {
	replace ln_emp_weo_hpf1000 = ln_emp_weo_hpf1000 + H1_ln_emp_weo_sm_`i'
}
drop *H1* 
bys ifscode: replace ln_emp_weo_hpf1000=. if ln_emp_weo_hpf1000 ==0
lab var ln_emp_weo_hpf1000 "Log Employment hp-filtered 1000 factor. WEO forecasts through 2018."

***************************************************************
* Gaps
***************************************************************

* lambda = 100
bys ifscode: gen u_star100 = ur - u_hpf100
lab var u_star100 " U minus U HPF100"
bys ifscode: gen y_star100 = logy - logy_hpf100 
lab var y_star100 " Y minus Y HPF100"
bys ifscode: gen emp_star100 = ln_emp - ln_emp_hpf100
lab var emp_star100 "log emp minus emp HPF100"  

bys ifscode: gen u_star100_07=ur-u_hpf100_07
lab var u_star100_07 " U minus U HPF100_07"
bys ifscode: gen y_star100_07 = logy - logy_hpf100_07
lab var y_star100_07 "Y minus Y HPF100_07"
bys ifscode: gen emp_star100_07 = ln_emp - ln_emp_hpf100_07
lab var emp_star100_07 "log emp minus emp HPF100_07"

bys ifscode: gen u_weo_star100 = ur_weo - u_weo_hpf100
lab var u_weo_star100 " U minus U HPF100. WEO forecasts through 2018."
bys ifscode: gen y_weo_star100 = logy_weo - logy_weo_hpf100 
lab var y_weo_star100 "Y minus Y HPF100. WEO forecasts through 2018."
bys ifscode: gen emp_weo_star100 = ln_emp_weo - ln_emp_weo_hpf100
lab var emp_weo_star100 "log emp minus emp HPF100. WEO forecasts through 2018."

* lambda = 1000
bys ifscode: gen u_star1000 = ur - u_hpf1000
lab var u_star1000 " U minus U HPF1000"
bys ifscode: gen y_star1000 = logy - logy_hpf1000 
lab var y_star1000 "Y minus Y HPF1000"
bys ifscode: gen emp_star1000 = ln_emp - ln_emp_hpf1000
lab var emp_star1000 "log emp minus emp HPF1000"

bys ifscode: gen u_star1000_07=ur-u_hpf1000_07
lab var u_star1000_07 " U minus U HPF1000_07"
bys ifscode: gen y_star1000_07 = logy - logy_hpf1000_07
lab var y_star1000_07 "Y minus Y HPF1000_07"
bys ifscode: gen emp_star1000_07 = ln_emp - ln_emp_hpf1000_07
lab var emp_star1000_07 "log emp minus emp HPF1000_07"

bys ifscode: gen u_weo_star1000 = ur_weo - u_weo_hpf1000
lab var u_weo_star1000 " U minus U HPF1000. WEO forecasts through 2018."
bys ifscode: gen y_weo_star1000 = logy_weo - logy_weo_hpf1000 
lab var y_weo_star1000 "Y minus Y HPF1000. WEO forecasts through 2018."
bys ifscode: gen emp_weo_star1000 = ln_emp_weo - ln_emp_weo_hpf1000
lab var emp_weo_star1000 "log emp minus emp HPF1000. WEO forecasts through 2018.mer"

***************************************************************
* Save after dropping excess years
***************************************************************

* 1979 - 2013
* (start in 1979 to allow 1980 to be first observation for first differences)

keep if (year>=1979 & year<=2013)

save "oecd_a_transformed_updated", replace




