log using"Actual and Fitted average employment Old vs New Recoveries.txt",replace t
********************************************
* Analysis of Okun's Law
*Average predicted employment change-old vs new recoveries
*Last modification: Nathalie Gonzalez
********************************************

********************************************
* Read in data
********************************************
global main = "\\was.int.imf.org\DeptShares\RES\DATA\Okun\other\1.data_appendix"
set more off
clear all
clear matrix
cd "$main\data"
use usa_q_transformed_updated.dta,clear
cd "$main\outputs"
keep if quarter <= tq(2013q4)
***************************
* Actual vs. fitted (E-E*)
***************************


* Variables

gen y = emp_chg1
gen x = y_chg
sort quarter
gen L1x = x[_n-1]
gen L2x = x[_n-2]
* Regression and fitted values
reg y x L1x L2x
local n = e(N)
local l = `n'^(1/4)
local l = round(`l')
newey y x L1x L2x,  lag(`l')
predict fitted_emp_change

*Recoveries

gen recovery_old = 0
gen recovery_new = 0

replace recovery_old =  1 if quarter >= tq(1950q1) & quarter<=tq(1950q4)
replace recovery_old =  1 if quarter >= tq(1954q3) & quarter<=tq(1955q2)
replace recovery_old =  1 if quarter >= tq(1958q3) & quarter<=tq(1959q2)
replace recovery_old =  1 if quarter >= tq(1961q2) & quarter<=tq(1962q1)
replace recovery_old =  1 if quarter >= tq(1971q1) & quarter<=tq(1971q4)
replace recovery_old =  1 if quarter >= tq(1975q2) & quarter<=tq(1976q1)
replace recovery_old =  1 if quarter >= tq(1980q4) & quarter<=tq(1981q3)
replace recovery_old =  1 if quarter >= tq(1983q1) & quarter<=tq(1983q4)
replace recovery_new =  1 if quarter >= tq(1991q2) & quarter<=tq(1992q1)
replace recovery_new =  1 if quarter >= tq(2002q1) & quarter<=tq(2002q4)
replace recovery_new =  1 if quarter >= tq(2009q3) & quarter<=tq(2010q2)


sum fitted_emp_change emp_chg1 if recovery_old
sum fitted_emp_change emp_chg1 if recovery_new

log close
