********************************************************************************
*Generating teh alphas an betas at the country level
********************************************************************************
********************************************************************************

cd "Q:\DATA\Okun\other\1.data_appendix\data"

**************************************************************************************
* Compute peak to trough (quarterly) changes in Y, U, and t
**************************************************************************************

* Read in quarterly data. To get the delta u delta y and the duration fo the episode
clear
clear matrix
use "Q:\DATA\Okun\other\1.data_appendix\data\oecd_q_transformed_updated.dta"
keep ifscode wdicode quarter gdp ur
sort ifscode quarter
save temp, replace
* Merge in peak and trough indicators.
preserve
clear matrix
clear
use "Q:\DATA\Okun\other\1.data_appendix\data\data"
sort ifscode quarter
keep ifscode quarter pt_output
save tempaux, replace
restore
merge ifscode quarter using tempaux
tab _merge
drop if _merge==2
drop _merge
* Compute peak-to-through variables
keep if (pt_output==1 | pt_output==2)
sort ifscode quarter
bys ifscode: gen quarterly_DY = 100*( (gdp/gdp[_n-1]) -1) if pt_output==2
bys ifscode: gen quarterly_DU = ur-ur[_n-1] if pt_output==2
bys ifscode: gen quarterly_BigT = quarter-quarter[_n-1] if pt_output==2
* Save variables for merging into annual data set later
keep if quarter>=tq(2007q1) & pt_output==2
keep ifscode quarterly_DY quarterly_DU quarterly_BigT 
sort ifscode
cap drop _merge
save temp, replace

**************************************************************************************
* Estimate Okun coefficients based on annual data (specification: changes)
* and compute predicted value for changes in U based on length of great recession.
**************************************************************************************

clear
clear matrix
use "Q:\DATA\Okun\other\1.data_appendix\data\oecd_a_transformed_updated"
sort ifscode
merge ifscode using temp
tab _merge
drop _merge
sort ifscode year

gen annual_okuna =.
gen annual_okunb =.
cap drop y
gen y = ur_chg
gen x = y_chg
gen urhat = .
gen urhat_se = .
gen alpha_T =.
gen beta_sumY=.
levelsof wdicode, local(list)
foreach cty of local list {

dis "`cty'"

regress   y x if year > 1979 & year <= 2013 & wdicode=="`cty'"

replace   annual_okuna = _b[_cons] if wdicode=="`cty'"
replace   annual_okunb = _b[x]  if wdicode=="`cty'"

sum quarterly_BigT if wdicode=="`cty'"
local quarterly_BigT = r(mean)
sum quarterly_DY if wdicode=="`cty'"
local quarterly_DY = r(mean)

cap lincom (`quarterly_BigT'*_b[_cons]*(1/4))  +  (_b[x]*`quarterly_DY')
replace alpha_T = `quarterly_BigT'*_b[_cons]*(1/4) if wdicode=="`cty'"
replace beta_sumY= _b[x]*`quarterly_DY' if wdicode=="`cty'"
local urhat = r(estimate)
local urhat_se = r(se)
cap replace urhat = `urhat' if wdicode=="`cty'"
cap replace urhat_se = `urhat_se' if wdicode=="`cty'"

}

* Save results in dataset for merging

keep if year==2000

reg quarterly_DU urhat
global R2_eq8 = round(e(r2_a), 0.001)
keep ifscode annual_okuna annual_okunb urhat urhat_se
sort ifscode
tempfile annual_okun_coefs
save `annual_okun_coefs', replace
ed
*****************************************************************************
* Read in data
*****************************************************************************

clear
clear matrix

global data = "$main\data"
global outputs = "$main\outputs"
use "$data/oecd_q_transformed_updated.dta"
save temp, replace

* Drop Greece (not in baseline Okun sample)
drop if wdicode=="GRC"

* Merge in annual Okun coefficients

cap drop _merge
sort ifscode
merge ifscode using "`annual_okun_coefs'"
tab _merge
drop _merge
sort ifscode quarter

* Merge in peak and trough indicators.
preserve
clear matrix
clear
use "$data/data"
sort ifscode quarter
keep ifscode quarter pt_output
save tempaux, replace
restore
merge ifscode quarter using tempaux
tab _merge
drop if _merge==2
drop _merge

******************************************************************
* Scatter plots
******************************************************************
cd"$outputs"
preserve
* Chart settings
local graphindex = 1
local title=""
* local title="Simple Scatter Plot"
local ytitle = "{&Sigma} {&Delta} {it:U}"
local xtitle = "- {&Sigma} {&Delta} {it:Y}"
* Variables 
* Keep only peak and trough observations 
* and compute peak-to-trough changes
keep if (pt_output==1 | pt_output==2)
sort ifscode quarter
bys ifscode: gen chg_u = ur-ur[_n-1] if pt_output==2
bys ifscode: gen y = gdp
bys ifscode: gen chg_y = 100*( (y/y[_n-1]) -1) if pt_output==2
keep if quarter>tq(2007q1)
keep if pt_output==2
cap drop y
gen y = chg_u
gen x = -chg_y
* Check R-squared (with constant)
reg y x
global adjR2_1 =round(e(r2_a), 0.01)
* Chart
twoway ///
(lfit y x, lpattern(dash) lcolor(black) sort) ///
(scatter y x,  mcolor(black) msize(tiny) msymbol(Oh) mlabel(wdicode) mlabposition(3) mlabsize(med) mlabcolor(black) ///
legend(off) lwidth(thin) lcolor(black) lpattern(dash) title("`title'") subtitle("") ytitle("`ytitle'", size(medlarge)) xtitle("`xtitle'", size(medlarge)) ///
ysize(4) xsize(9.0) ylabel(0(2)8) xlabel(0(2)10) ///
saving(Figure_5A, replace) )
sort country
list country quarter y x 
restore
* legend(off) lwidth(thin) lcolor(black) lpattern(dash) title("`title'") subtitle("Adjusted R-squared = `subtitle' percent") ytitle("`ytitle'", size(medlarge)) xtitle("`xtitle'", size(medlarge)) ///

preserve
* Chart settings
local graphindex = 2
local title=""
* local title="Adjusting for T"global
local ytitle = "{&Sigma} {&Delta} {it:U}"
local xtitle = "{&alpha} {it:T}  +  {&beta} {&Sigma} {&Delta} {it:Y}"
* Variables 
* Keep only peak and trough observations 
* and compute peak-to-trough changes
keep if (pt_output==1 | pt_output==2)
sort ifscode quarter
bys ifscode: gen chg_u = ur-ur[_n-1] if pt_output==2
bys ifscode: gen y = gdp
bys ifscode: gen chg_y = 100*( (y/y[_n-1]) -1) if pt_output==2
bys ifscode: gen BigT = quarter-quarter[_n-1] if pt_output==2
keep if quarter>tq(2007q1)
keep if pt_output==2
cap drop y
gen y = chg_u
gen x = -chg_y
* Find R-squared (*without* constant)
reg y x BigT, nocons
global adj_r2_2=round(e(r2_a), 0.01)
global alpha =round( _b[BigT], 0.01)
global alpha_se = round(_se[BigT], 0.01)
global beta = round(_b[x], 0.01)
global beta_se = round(_se[x], 0.01)
* Plot line (*without* constant)
predict yhat2
* Chart
twoway ///
(lfit yhat2 yhat2, lpattern(dash) lcolor(black) sort) ///
(scatter y yhat2,  mcolor(black) msize(tiny) msymbol(Oh) mlabel(wdicode) mlabposition(12) mlabsize(med) mlabcolor(black) ///
legend(off) lwidth(thin) lcolor(black) lpattern(dash) title("`title'") subtitle("") ytitle("`ytitle'", size(medlarge)) xtitle("`xtitle'", size(medlarge)) ///
ysize(4) xsize(9.0) ///
saving(Figure_5B, replace)  )
sort country
list country y x
restore
* ysize(4) xsize(9.0) ylabel(0(2)8) xlabel(0(2)10) ///
* Note: fitted line is equivalent to regressing y on yhat2 with no constant (yields slope of 1).

preserve
* Chart settings
local graphindex = 3
local title=""
* local title="Adjusting for T and Country-specific Coeficients"
local ytitle = "{&Sigma} {&Delta} {it:U}"
local xtitle = "{&alpha}{subscript:i} {it:T}  +  {&beta}{subscript:i} {&Sigma} {&Delta} {it:Y}"
* Variables 
* Keep only peak and trough observations 
* and compute peak-to-trough changes
keep if (pt_output==1 | pt_output==2)
sort ifscode quarter
bys ifscode: gen chg_u = ur-ur[_n-1] if pt_output==2
bys ifscode: gen y = gdp
bys ifscode: gen chg_y = 100*( (y/y[_n-1]) -1) if pt_output==2
bys ifscode: gen BigT = quarter-quarter[_n-1] if pt_output==2
keep if quarter>tq(2007q1)
keep if pt_output==2

* Chart
twoway ///
(lfit  chg_u urhat, lpattern(solid) lcolor(black) sort) ///
(scatter  chg_u urhat ,  mcolor(black) msize(tiny) msymbol(Oh) mlabel(wdicode) mlabposition(12) mlabsize(med) mlabcolor(black) ///
legend(off) lwidth(thin) lcolor(black) lpattern(dash) title("`title'") subtitle("") ytitle("`ytitle'", size(medlarge)) xtitle("`xtitle'", size(medlarge)) ///
ysize(4) xsize(9.0) ///
saving(Figure_5C, replace) )
sort country
rename urhat chg_u_hat
* list country quarter chg_u chg_y chg_u_hat BigT annual_okuna annual_okunb yhat2 y x
gen resid = chg_u - chg_u_hat
clist country chg_u chg_u_hat resid, noobs
restore
* ylabel(0(2)8) xlabel(0(2)10) 


* Calculations for text
* Length of recessions
preserve
keep if quarter>tq(2007q1)
keep if (pt_output==1)
list country quarter pt_output
* Most countries' "alpha" estimates are about...
restore
sum annual_okuna, d
global alpha_avg =round(r(mean), 0.01)
global alpha_avg_4 = round((r(mean)/4), 0.01)

display "AdjR2 page26 = $adjR2_1"
display "NUMBERS EQUATION 7 IN THE PAPER"
display "alpha= $alpha"
display "alpha_se= $alpha_se"
display "beta= $beta"
display "beta_se= $beta_se"
display "AdjR2 eq 7 = $adj_r2_2"
display "NUMBERS EQUATION 8 IN THE PAPER"
display "average alpha = $alpha_avg"
display "average alpha/4 = $alpha_avg_4"
display "R-squared eq 8  = $R2_eq8"
