**************************************************************************************
* Analysis of Okun's Law relation
* Contacts: Ezgi Ozturk and Daniel Leigh
**************************************************************************************

**************************************************************************************
* Read in data
**************************************************************************************

cd "$main\data"

clear
clear matrix
use "$main\data\oecd_a_transformed_updated"
sort wdicode year
save temp, replace

* Merge in employment protection data
preserve
clear
clear matrix
use empl_prot_oecd.dta
save tempaux, replace
rename ctry wdicode
keep wdicode year ep_v1
sort wdicode year
save tempaux, replace
restore

merge wdicode year using tempaux
drop if _merge==2
drop _merge
sort ifscode year
save temp, replace

*****************************************************************************************************************
* Estimate country-specific Okun coefficients, and store the results
* Levels version (HPF lambda = 100)
*****************************************************************************************************************

* Variables
gen y = u_star100
gen x = y_star100
gen beta = .
gen se = .
* Open country loop
levelsof wdicode, local(list)
foreach cty of local list {
	* Regression
	reg y x if wdicode=="`cty'", nocons
	lincom _b[x]
	local coef = r(estimate)
	local se = r(se)
	replace beta = `coef' 	if wdicode=="`cty'"
	replace se = `se' 		if wdicode=="`cty'"
}

*****************************************************************************************************************
* Compute average unemployment rate and EPA index
*****************************************************************************************************************

tab year if ep_v1~=.
sort ifscode year 
by ifscode:egen mean_ep_v1   = mean(ep_v1)  if year >1979
by ifscode:egen mean_ur   = mean(ur)  if year >1979

****************************************************************************************************
* Combined Chart
**************************************************************************************************

preserve
sort ifscode 
cap drop y
cap drop x
bys ifscode: gen y = beta
bys ifscode: gen x = mean_ur
reg y x
local coef = _b[x]
local tstat = _b[x]/_se[x]
local coef = round(`coef',.01)
local tstat = round(`tstat',.01)
local ytitle = "Okun coefficient"
*change
local xtitle = "Average unemployment rate"
*change
local graphindex = "1"
local title=""
twoway ///
(lfit y x, ///
legend(off) lwidth(thin) lcolor(black) lpattern(dash) title("`title'") ytitle("`ytitle'") xtitle("`xtitle'")) ///
(scatter y x,  mlabel(wdicode) mcolor(black) msize(small) msymbol(Oh) mlabsize(small) mlabcolor(black) ///
 scheme(s2color)), name(a, replace)
restore
* ysize(5.5) xsize(9.0) ///

preserve
sort ifscode 
cap drop y
cap drop x
bys ifscode: gen y = beta
bys ifscode: gen x = mean_ep_v1
reg y x
local coef = _b[x]
local tstat = _b[x]/_se[x]
local coef = round(`coef',.01)
local tstat = round(`tstat',.01)
local ytitle = "Okun coefficient"
*change
local xtitle = "OECD overall employment protection index"
*change
local graphindex = "2"
local title=""
twoway ///
(lfit y x, ///
legend(off) lwidth(thin) lcolor(black) lpattern(dash) title("`title'") ytitle("`ytitle'") xtitle("`xtitle'")) ///
(scatter y x,  mlabel(wdicode) mcolor(black) msize(small) msymbol(Oh) mlabsize(small) mlabcolor(black) ///
 scheme(s2color)) , name(b,replace)
restore

cd"$main\outputs" 
graph combine a b, ycommon saving(Figure_6,replace) scheme(s2color)


