*****************************************************************************************************************
* Analysis:  Role of recession dummy.  iF YOU REPLACE T3 FOR Table3 and uncomment line 11 you can replicate the table in the current version of the paper. 
*The product of running the file as it is is the result constructing the data from scratch with the files incluede in the folder
* Contact: FGONZALEZPRIETO@IMF.ORG
*****************************************************************************************************************

* Read in the data

clear all
cd "$main\data"
use usa_q_transformed_updated.dta,clear
cd "$main\outputs"
sort quarter
set more off

* Sample

drop if quarter>tq(2013q4)
 matrix Table3U= J(4,24,.)
matrix Table3L= J(3,8,.)
*****************************************************************************************************************
* U-Y Okun Relation: Levels
*****************************************************************************************************************

preserve
* Settings
local title = "baseline"
* Variables
gen y = u_star1600
gen x = y_star1600
gen z = recession 
gen L1y = L1.y
gen L1x = L1.x
gen L1z = L1.z
gen L2y = L2.y
gen L2x = L2.x
gen L2z = L2.z
* Regression
* OLS

reg y x L1x L2x, nocons
matrix Table3L[1,1]  = e(N)
matrix Table3L[2,1] = e(r2_a)
matrix Table3L[3,1]  = e(rmse)

local n = e(N)
local l = `n'^(1/4)
local l = round(`l')
* NW
newey y x L1x L2x, nocons lag(`l')
lincom _b[x] + _b[L1x] + _b[L2x]
matrix Table3U[2,1] = r(estimate)
matrix Table3U[2,2] = r(se)
test _b[x] + _b[L1x] + _b[L2x]  = 0
matrix Table3U[2,3] = r(p)

restore

preserve
* Settings
local title = "dummies"
* Variables
gen y = u_star1600
gen x = y_star1600
gen z = recession 
gen L1y = L1.y
gen L1x = L1.x
gen L1z = L1.z
gen L2y = L2.y
gen L2x = L2.x
gen L2z = L2.z
* Regression
* OLS
reg y x L1x L2x z L1z L2z, nocons
matrix Table3L[1,2]  = e(N)
matrix Table3L[2,2] = e(r2_a)
matrix Table3L[3,2]  = e(rmse)
local n = e(N)
local l = `n'^(1/4)
local l = round(`l')
* NW
newey y x L1x L2x z L1z L2z, nocons lag(`l')
lincom _b[x] + _b[L1x] + _b[L2x]
matrix Table3U[2,4] = r(estimate)
matrix Table3U[2,5] = r(se)
test _b[x] + _b[L1x] + _b[L2x]  = 0
matrix Table3U[2,6] = r(p)

lincom _b[z] + _b[L1z] + _b[L2z]
matrix Table3U[3,4] = r(estimate)
matrix Table3U[3,5] = r(se)
test _b[z] + _b[L1z] + _b[L2z]  = 0
matrix Table3U[3,6] = r(p)

restore

preserve
* Settings
local title = "interaction"
* Variables
gen y = u_star1600
gen x = y_star1600
gen z = recession 
gen i = x*z
gen L1y = L1.y
gen L1x = L1.x
gen L1z = L1.z
gen L1i = L1.i
gen L2y = L2.y
gen L2x = L2.x
gen L2z = L2.z
gen L2i = L2.i
* Regression
* OLS
reg y x L1x L2x i L1i L2i, nocons
matrix Table3L[1,3]  = e(N)
matrix Table3L[2,3] = e(r2_a)
matrix Table3L[3,3]  = e(rmse)
local n = e(N)
local l = `n'^(1/4)
local l = round(`l')
* NW
newey y x L1x L2x i L1i L2i, nocons lag(`l')
lincom _b[x] + _b[L1x] + _b[L2x]
matrix Table3U[2,7] = r(estimate)
matrix Table3U[2,8] = r(se)
test _b[x] + _b[L1x] + _b[L2x]  = 0
matrix Table3U[2,9] = r(p)

lincom _b[i] + _b[L1i] + _b[L2i]
matrix Table3U[4,7] = r(estimate)
matrix Table3U[4,8] = r(se)
test _b[i] + _b[L1i] + _b[L2i]  = 0
matrix Table3U[4,9] = r(p)

restore

preserve
* Settings
local title = "both"
* Variables
gen y = u_star1600
gen x = y_star1600
gen z = recession 
gen i = x*z
gen L1y = L1.y
gen L1x = L1.x
gen L1z = L1.z
gen L1i = L1.i
gen L2y = L2.y
gen L2x = L2.x
gen L2z = L2.z
gen L2i = L2.i
* Regression
* OLS
reg y x L1x L2x z L1z L2z i L1i L2i, nocons
matrix Table3L[1,4]  = e(N)
matrix Table3L[2,4] = e(r2_a)
matrix Table3L[3,4]  = e(rmse)
local n = e(N)
local l = `n'^(1/4)
local l = round(`l')
* NW
newey y x L1x L2x z L1z L2z i L1i L2i, nocons lag(`l')
lincom _b[x] + _b[L1x] + _b[L2x]
matrix Table3U[2,10] = r(estimate)
matrix Table3U[2,11] = r(se)
test _b[x] + _b[L1x] + _b[L2x]  = 0
matrix Table3U[2,12] = r(p)

lincom _b[z] + _b[L1z] + _b[L2z]
matrix Table3U[3,10] = r(estimate)
matrix Table3U[3,11] = r(se)
test _b[z] + _b[L1z] + _b[L2z]  = 0
matrix Table3U[3,12] = r(p)

lincom _b[i] + _b[L1i] + _b[L2i]
matrix Table3U[4,10] = r(estimate)
matrix Table3U[4,11] = r(se)
test _b[i] + _b[L1i] + _b[L2i]  = 0
matrix Table3U[4,12] = r(p)
restore



*****************************************************************************************************************
* U-Y Okun Relation: Changes
*****************************************************************************************************************

preserve
* Settings
local title = "baseline"
* Variables
gen y = ur_chg
gen x = y_chg
gen z = recession 
gen L1y = L1.y
gen L1x = L1.x
gen L1z = L1.z
gen L2y = L2.y
gen L2x = L2.x
gen L2z = L2.z
* Regression
* OLS
reg y x L1x L2x
matrix Table3L[1,5]  = e(N)
matrix Table3L[2,5] = e(r2_a)
matrix Table3L[3,5]  = e(rmse)
local n = e(N)
local l = `n'^(1/4)
local l = round(`l')
* NW
newey y x L1x L2x, lag(`l')
matrix Table3U[1,13] = _b[_cons]
matrix Table3U[1,14] = _se[_cons]
test _b[_cons]=0
matrix Table3U[1,15] = r(p)

lincom _b[x] + _b[L1x] + _b[L2x]
matrix Table3U[2,13] = r(estimate)
matrix Table3U[2,14] = r(se)
test _b[x] + _b[L1x] + _b[L2x]  = 0
matrix Table3U[2,15] = r(p)

global hat_09q1_norecession= round(-1.4*_b[x]-2.1*_b[L1x]-0.5*_b[L2x]+_b[_cons], 0.1)
display $hat_09q1_norecession
restore

preserve
* Settings
local title = "dummies"
* Variables
gen y = ur_chg
gen x = y_chg
gen z = recession 
gen L1y = L1.y
gen L1x = L1.x
gen L1z = L1.z
gen L2y = L2.y
gen L2x = L2.x
gen L2z = L2.z
* Regression
* OLS
reg y x L1x L2x z L1z L2z
matrix Table3L[1,6]  = e(N)
matrix Table3L[2,6] = e(r2_a)
matrix Table3L[3,6]  = e(rmse)
local n = e(N)
local l = `n'^(1/4)
local l = round(`l')
* NW
newey y x L1x L2x z L1z L2z, lag(`l')

matrix Table3U[1,16] = _b[_cons]
matrix Table3U[1,17] = _se[_cons]
test _b[_cons]=0
matrix Table3U[1,18] = r(p)

lincom _b[x] + _b[L1x] + _b[L2x]
matrix Table3U[2,16] = r(estimate)
matrix Table3U[2,17] = r(se)
test _b[x] + _b[L1x] + _b[L2x]  = 0
matrix Table3U[2,18] = r(p)

lincom _b[z] + _b[L1z] + _b[L2z]
matrix Table3U[3,16] = r(estimate)
matrix Table3U[3,17] = r(se)
test _b[z] + _b[L1z] + _b[L2z]  = 0
matrix Table3U[3,18] = r(p)
restore

preserve
* Settings
local title = "interaction"
* Variables
gen y = ur_chg
gen x = y_chg
gen z = recession 
gen i = x*z
gen L1y = L1.y
gen L1x = L1.x
gen L1z = L1.z
gen L1i = L1.i
gen L2y = L2.y
gen L2x = L2.x
gen L2z = L2.z
gen L2i = L2.i
* Regression
* OLS
reg y x L1x L2x i L1i L2i
matrix Table3L[1,7]  = e(N)
matrix Table3L[2,7] = e(r2_a)
matrix Table3L[3,7]  = e(rmse)
local n = e(N)
local l = `n'^(1/4)
local l = round(`l')
* NW
newey y x L1x L2x i L1i L2i, lag(`l')
matrix Table3U[1,19] = _b[_cons]
matrix Table3U[1,20] = _se[_cons]
test _b[_cons]=0
matrix Table3U[1,21] = r(p)

lincom _b[x] + _b[L1x] + _b[L2x]
matrix Table3U[2,19] = r(estimate)
matrix Table3U[2,20] = r(se)
test _b[x] + _b[L1x] + _b[L2x]  = 0
matrix Table3U[2,21] = r(p)

lincom _b[i] + _b[L1i] + _b[L2i]
matrix Table3U[4,19] = r(estimate)
matrix Table3U[4,20] = r(se)
test _b[i] + _b[L1i] + _b[L2i]  = 0
matrix Table3U[4,21] = r(p)



restore

preserve
* Settings
local title = "both"
* Variables
gen y = ur_chg
gen x = y_chg
gen z = recession 
gen i = x*z
gen L1y = L1.y
gen L1x = L1.x
gen L1z = L1.z
gen L1i = L1.i
gen L2y = L2.y
gen L2x = L2.x
gen L2z = L2.z
gen L2i = L2.i
* Regression
* OLS
reg y x L1x L2x z L1z L2z i L1i L2i
matrix Table3L[1,8]  = e(N)
matrix Table3L[2,8] = e(r2_a)
matrix Table3L[3,8]  = e(rmse)
local n = e(N)
local l = `n'^(1/4)
local l = round(`l')
* NW
newey y x L1x L2x z L1z L2z i L1i L2i, lag(`l')

matrix Table3U[1,22] = _b[_cons]
matrix Table3U[1,23] = _se[_cons]
test _b[_cons]=0
matrix Table3U[1,24] = r(p)

lincom _b[x] + _b[L1x] + _b[L2x]
matrix Table3U[2,22] = r(estimate)
matrix Table3U[2,23] = r(se)
test _b[x] + _b[L1x] + _b[L2x]  = 0
matrix Table3U[2,24] = r(p)

lincom _b[z] + _b[L1z] + _b[L2z]
matrix Table3U[3,22] = r(estimate)
matrix Table3U[3,23] = r(se)
test _b[z] + _b[L1z] + _b[L2z]  = 0
matrix Table3U[3,24] = r(p)

lincom _b[i] + _b[L1i] + _b[L2i]
matrix Table3U[4,22] = r(estimate)
matrix Table3U[4,23] = r(se)
test _b[i] + _b[L1i] + _b[L2i]  = 0
matrix Table3U[4,24] = r(p)
global hat_09q1_recession= round(-1.4*_b[x]-2.1*_b[L1x]-0.5*_b[L2x]-1.4*_b[i] -2.1*_b[L1i] -0.5*_b[L2i]+ _b[z] + _b[L1z] + _b[L2z] +_b[_cons], 0.1)
display $hat_09q1_recession
restore

mat coln Table3L = "Lbaseline" "Ldummies" "Linteraction" "Lboth"  "Cbaseline" "Cdummies" "Cinteraction" "Cboth"
mat rown Table3L = "Obs" "Adjr2" "RMSE"
mat coln Table3U = "C1_b"	"C1_se"	"C1_pv"	"C2_b"	"C2_se"	"C2_pv"	"C3_b"	"C3_se"	"C3_pv"	"C4_b"	"C4_se"	"C4_pv"	"C5_b"	"C5_se"	"C5_pv"	"C6_b"	"C6_se"	"C6_pv"	"C7_b"	"C7_se"	"C7_pv"	"C8_b"	"C8_se"	"C8_pv"
mat rown Table3U= "R1_alpha" "R2_b0+b1+b2" "R3_g0+g1+g2" "R4_d0+d1+d2" 

clear
svmat2 Table3L, names(col)  rnames(title)
tostring Lbaseline Ldummies Linteraction Lboth Cbaseline Cdummies Cinteraction Cboth , replace force format (%4.3f)
order title

tempfile stats
save `stats'
clear
svmat2 Table3U, names(col)  rnames(title)
forvalues x=1/8{

tostring C`x'_b C`x'_se , replace force format (%4.3f)
replace C`x'_b= C`x'_b + "***" if C`x'_pv<0.01
replace C`x'_b= C`x'_b + "**" if C`x'_pv<0.05 & C`x'_pv>=0.01
replace C`x'_b= C`x'_b + "*" if C`x'_pv<0.1 & C`x'_pv>=0.05
replace C`x'_se = "("+C`x'_se+")" if C`x'_se!="."
drop C`x'_pv
}

reshape long C1 C2 C3 C4 C5 C6 C7 C8 , i(title) j(c) string
local i =1
foreach x in "Lbaseline" "Ldummies" "Linteraction" "Lboth"  "Cbaseline" "Cdummies" "Cinteraction" "Cboth"{ 
rename C`i' `x'
local i = `i'+1
} 
append using `stats' ,force
drop c
export excel Table_3, first(var) replace
