********************************************
* Analysis of Okun's Law
* Contact: Nathalie Gonzalez
********************************************

********************************************
* Read in data
********************************************

set more off
clear
clear matrix

cd "$main\data"
use usa_q_transformed_updated.dta,clear
cd "$main\outputs"
tsset quarter
save temp, replace

***************************
* Levels
***************************

preserve
* Variables
cap drop y
cap drop x
sort quarter
gen y = u_star1600
gen L1y = L1.y
gen x = y_star1600
gen L1x = L1.x
gen L2x = L2.x
* Sample
keep if (quarter >= tq(1948q1) & quarter <= tq(2013q4))
* Sub-sample variables
	gen x1 = 0
	gen L1x1 = 0
	gen L2x1 = 0
	gen x2 = 0
	gen L1x2 = 0
	gen L2x2 = 0
	replace x1 = x if quarter<tq(1984q1)
	replace L1x1 = L1x if quarter<tq(1984q1)
	replace L2x1 = L2x if quarter<tq(1984q1)
	replace x2 = x if quarter>=tq(1984q1)
	replace L1x2 = L1x if quarter>=tq(1984q1)
	replace L2x2 = L2x if quarter>=tq(1984q1)
matrix table4u = J(3,18,.)

matrix table4l=J(3,6,.)

	* Regressions
	* Baseline (restricted version):
	* OLS. Lag selection. l = (n)^(1/4).  
	reg y x L1x L2x, noconstant
	local n = e(N)
	local l = `n'^(1/4)
	local l = round(`l')
	matrix table4l[3,1] = e(r2_a)
	newey y x L1x L2x, noconstant lag(`l')
	lincom x + L1x + L2x
	matrix table4u[1,1] = r(estimate)
	matrix table4u[1,2] = r(se)
	test x + L1x + L2x=0
	matrix table4u[1,3] = r(p)
	
	* With break:
	* OLS. Lag selection. l = (n)^(1/4).  
	reg y x1 L1x1 L2x1 x2 L1x2 L2x2, noconstant
	local n = e(N)
	local l = `n'^(1/4)
	local l = round(`l')
	matrix table4l[3,2] = e(r2_a)
	newey y x1 L1x1 L2x1 x2 L1x2 L2x2, noconstant lag(`l')
	* Store coefficients
	lincom x1 + L1x1 + L2x1
	matrix table4u [2,4]= r(estimate)
	matrix table4u [2,5]=  r(se)
	test x1 + L1x1 + L2x1=0
	matrix table4u [2,6]= r(p)
		
	lincom x2 + L1x2 + L2x2
	matrix table4u [3,4]= r(estimate)
	matrix table4u [3,5] = r(se)
	test x2 + L1x2 + L2x2=0
	matrix table4u [3,6] = r(p)
	* Test, store test statistic
	test x1+L1x1+L2x1 = x2+L1x2+L2x2 
	matrix table4l[1,2] = r(F)
	matrix table4l[2,2] =  r(p)
	restore	



***************************
* Changes
***************************

preserve
* Variables
cap drop y
cap drop x
sort quarter
gen y = ur_chg
gen L1y = L1.y
gen x = y_chg
gen L1x = L1.x
gen L2x = L2.x
* Sample
keep if (quarter >= tq(1948q1) & quarter <= tq(2013q4))
* Sub-sample variables
	gen x1 = 0
	gen L1x1 = 0
	gen L2x1 = 0
	gen x2 = 0
	gen L1x2 = 0
	gen L2x2 = 0
	replace x1 = x if quarter<tq(1984q1)
	replace L1x1 = L1x if quarter<tq(1984q1)
	replace L2x1 = L2x if quarter<tq(1984q1)
	replace x2 = x if quarter>=tq(1984q1)
	replace L1x2 = L1x if quarter>=tq(1984q1)
	replace L2x2 = L2x if quarter>=tq(1984q1)
* Regressions
	* Baseline (restricted version):
	* OLS. Lag selection. l = (n)^(1/4).  
	reg y x L1x L2x
	local n = e(N)
	local l = `n'^(1/4)
	local l = round(`l')
	matrix table4l[3,4] = e(r2_a)
	newey y x L1x L2x, lag(`l')
	lincom x + L1x + L2x
	matrix table4u[1,10] = r(estimate)
	matrix table4u[1,11] = r(se)
	test x + L1x + L2x=0
	matrix table4u[1,12] = r(p)
	
	* With break:
	* OLS. Lag selection. l = (n)^(1/4).  
	reg y x1 L1x1 L2x1 x2 L1x2 L2x2
	local n = e(N)
	local l = `n'^(1/4)
	local l = round(`l')
	matrix table4l[3,5] = e(r2_a)
	newey y x1 L1x1 L2x1 x2 L1x2 L2x2, lag(`l')
	* Store coefficients
	lincom x1 + L1x1 + L2x1
	matrix table4u[2,13] = r(estimate)
	matrix table4u[2,14] = r(se)
	test x1 + L1x1 + L2x1 =0
	matrix table4u[2,15] = r(p)
	
	lincom x2 + L1x2 + L2x2
	matrix table4u[3,13] = r(estimate)
	matrix table4u[3,14] =r(se)
	test x2 + L1x2 + L2x2=0
	matrix table4u[3,15] =r(se)
	* Test, store test statistic
	test x1+L1x1+L2x1 = x2+L1x2+L2x2 
	matrix table4l[1,5]= r(F)
	matrix table4l[2,5] = r(p)
	
restore	
***************************
* Sup Wal test
* of break point
* at unknown date
***************************

preserve
* Set up
local graphindex = 1
* Variables
cap drop y
cap drop x
sort quarter
gen y = u_star1600
gen L1y = L1.y
gen x = y_star1600
gen L1x = L1.x
gen L2x = L2.x
gen F = .
gen b1 = .
gen b2 = .
gen se1 = .
gen se2 = .
gen p1 = .
gen p2= .
gen r2 = .
gen p = .
* Sample
keep if (quarter >= tq(1948q1) & quarter <= tq(2013q4))
* Loop
local cutoff = round(0.15*(tq(2013q4)-tq(1948q1)))
local start = tq(1948q1) + `cutoff'
local finish = tq(2013q4) - `cutoff'
set more off
forval quarter = `start'/`finish' {
* quietly forval quarter = `start'/`start' {
	gen x1 = 0
	gen L1x1 = 0
	gen L2x1 = 0
	gen x2 = 0
	gen L1x2 = 0
	gen L2x2 = 0
	gen a1 = 0
	gen a2 = 0
	replace a1 = 1 if quarter<=`quarter'
	replace a2 = 1 if quarter>`quarter'
	replace x1 = x*a1
	replace L1x1 = L1x*a1
	replace L2x1 = L2x*a1
	replace x2 = x if quarter>`quarter'
	replace L1x2 = L1x if quarter>`quarter'
	replace L2x2 = L2x if quarter>`quarter'
	* Regression
	* Newey lag selection.  l = (n)^(1/4).  
	reg y x1 L1x1 L2x1 x2 L1x2 L2x2, noconstant
	local n = e(N)
	local l = `n'^(1/4)
	local l = round(`l')
	newey y x1 L1x1 L2x1 x2 L1x2 L2x2, noconstant lag(`l')
	* Test, store test statistic
	di("Testing quarter:")
	tab quarter if quarter == `quarter'
	test x1+L1x1+L2x1 = x2+L1x2+L2x2 
	local F = r(F)
	replace F = `F' if quarter==`quarter'
	newey y x1 L1x1 L2x1 x2 L1x2 L2x2, noconstant lag(`l')
	lincom x1 + L1x1 + L2x1
	local b1 = r(estimate)
	local se1 = r(se)
	test x1 + L1x1 + L2x1=0
	local p1 = r(p)
	replace b1 = `b1' if quarter==`quarter'
	replace se1 = `se1' if quarter==`quarter'
	replace p1 = `p1' if quarter==`quarter'
	lincom x2 + L1x2 + L2x2
	local b2 = r(estimate)
	local se2 = r(se)
	test x2 + L1x2 + L2x2 = 0 
	local p2 = r(p)
	replace b2 = `b2' if quarter==`quarter'
	replace se2 = `se2' if quarter==`quarter'
	replace p2 = `p2' if quarter==`quarter'
	test x1 + L1x1 + L2x1= x2 + L1x2 + L2x2 	
	replace p =r(p) if quarter==`quarter'	
	* Get R2 (use OLS regression for this, as Newey doesn't report R2)
	reg y x1 L1x1 L2x1 x2 L1x2 L2x2, noconstant
	local r2 = e(r2_a)
	replace r2 = `r2' if quarter==`quarter'	
	cap drop a1 a2 *x1 *x2
}
* Chart
* Critical values: http://www.ssc.wisc.edu/~bhansen/390/390Lecture20.pdf

sum F
local maxF = r(max)  

keep if F==`maxF'
sum b1
matrix table4u[2,7]= r(mean)
sum se1
matrix table4u[2,8]= r(mean)
sum p1
matrix table4u[2,9]= r(mean)
sum b2
matrix table4u[3,7]= r(mean)
sum se2
matrix table4u[3,8]= r(mean)
sum p2
matrix table4u[3,9]= r(mean)
sum F
matrix table4l[1,3]= r(mean)
sum p
matrix table4l[2,3]= r(mean)
sum r2
matrix table4l[3,3]= r(mean)
sum quarter 
local break=1960+r(mean)/4
restore
*Changes
***************************
* Sup Wal test
* of break point
* at unknown date
***************************

preserve
* Set up
local graphindex = 1
* Variables
cap drop y
cap drop x
sort quarter
gen y = ur_chg
gen L1y = L1.y
gen x = y_chg
gen L1x = L1.x
gen L2x = L2.x
gen F = .
gen b1 = .
gen b2 = .
gen se1 = .
gen se2 = .
gen p1 = .
gen p2= .
gen r2 = .
gen p = .
* Sample
keep if (quarter >= tq(1948q1) & quarter <= tq(2013q4))
* Loop
local cutoff = round(0.15*(tq(2013q4)-tq(1948q1)))
local start = tq(1948q1) + `cutoff'
local finish = tq(2013q4) - `cutoff'
set more off
forval quarter = `start'/`finish' {
* quietly forval quarter = `start'/`start' {
	gen x1 = 0
	gen L1x1 = 0
	gen L2x1 = 0
	gen x2 = 0
	gen L1x2 = 0
	gen L2x2 = 0
	gen a1 = 0
	gen a2 = 0
	replace a1 = 1 if quarter<=`quarter'
	replace a2 = 1 if quarter>`quarter'
	replace x1 = x*a1
	replace L1x1 = L1x*a1
	replace L2x1 = L2x*a1
	replace x2 = x if quarter>`quarter'
	replace L1x2 = L1x if quarter>`quarter'
	replace L2x2 = L2x if quarter>`quarter'
	* Regression
	* Newey lag selection.  l = (n)^(1/4).  
	reg y x1 L1x1 L2x1 x2 L1x2 L2x2
	local n = e(N)
	local l = `n'^(1/4)
	local l = round(`l')
	newey y x1 L1x1 L2x1 x2 L1x2 L2x2, lag(`l')
	* Test, store test statistic
	di("Testing quarter:")
	tab quarter if quarter == `quarter'
	test x1+L1x1+L2x1 = x2+L1x2+L2x2 
	local F = r(F)
	replace F = `F' if quarter==`quarter'
	replace p = r(p)  if quarter==`quarter'
	newey y x1 L1x1 L2x1 x2 L1x2 L2x2, lag(`l')
	lincom x1 + L1x1 + L2x1
	local b1 = r(estimate)
	local se1 = r(se)
	replace b1 = `b1' if quarter==`quarter'
	replace se1 = `se1' if quarter==`quarter'
	 test x1 + L1x1 + L2x1 = 0
	 replace p1 = r(p) if quarter==`quarter'
	lincom x2 + L1x2 + L2x2
	local b2 = r(estimate)
	local se2 = r(se)
	replace b2 = `b2' if quarter==`quarter'
	replace se2 = `se2' if quarter==`quarter'
	 test x2 + L1x2 + L2x2 = 0
	  replace p2 = r(p) if quarter==`quarter'
	* Get R2 (use OLS regression for this, as Newey doesn't report R2)
	reg y x1 L1x1 L2x1 x2 L1x2 L2x2
	local r2 = e(r2_a)
	replace r2 = `r2' if quarter==`quarter'	
	cap drop a1 a2 *x1 *x2
}

sum F
local maxF = r(max)  

keep if F>=`maxF'*.99 & F~=.
sum quarter 
local break_c=1960+r(mean)/4
sum b1
matrix table4u[2,16]= r(mean)
sum se1
matrix table4u[2,17]= r(mean)
sum p1
matrix table4u[2,18]= r(mean)
sum b2
matrix table4u[3,16]= r(mean)
sum se2
matrix table4u[3,17]= r(mean)
sum p2
matrix table4u[3,18]= r(mean)
sum F
matrix table4l[1,6]= r(mean)
sum p
matrix table4l[2,6]= r(mean)
sum r2
matrix table4l[3,6]= r(mean)



mat coln table4l = "LevelsB" "LFixed1984Q1" "LEstimated" "ChangesB" "CFixed1984Q1" "CEstimated"
mat coln table4u = "C1_b"	"C1_se"	"C1_pv"	"C2_b"	"C2_se"	"C2_pv"	"C3_b"	"C3_se"	"C3_pv"	"C4_b"	"C4_se"	"C4_pv"	"C5_b"	"C5_se"	"C5_pv"	"C6_b"	"C6_se"	"C6_pv"
matrix rowname table4u = "R1_b0+b1+b2" "R2_tLtb0+b1+b2" "R3_tGtb0+b1+b2" 
matrix rownames table4l  = "F" "p" "AdjR2"

clear
svmat2 table4l, names(col)  rnames(title)
tostring LevelsB LFixed1984Q1 LEstimated ChangesB CFixed1984Q1 CEstimated, replace force format (%4.3f)
order title
tempfile stats
save `stats'
clear
svmat2 table4u , names(col)  rnames(title)
forvalues x=1/6{

tostring C`x'_b C`x'_se , replace force format (%4.3f)
replace C`x'_b= C`x'_b + "***" if C`x'_pv<0.01
replace C`x'_b= C`x'_b + "**" if C`x'_pv<0.05 & C`x'_pv>=0.01
replace C`x'_b= C`x'_b + "*" if C`x'_pv<0.1 & C`x'_pv>=0.05
replace C`x'_se = "("+C`x'_se+")" if C`x'_se!="."
drop C`x'_pv
}
reshape long C1 C2 C3 C4 C5 C6, i(title) j(c) string
local i =1
foreach x in "LevelsB" "LFixed1984Q1" "LEstimated" "ChangesB" "CFixed1984Q1" "CEstimated"{ 
rename C`i' `x'
local i = `i'+1
} 
append using `stats' ,force
drop c

display  "Break Levels: `break' Break changes: `break_c'"
gen Break_Levels = `break'  if _n==1
gen Break_Changes = `break_c'  if _n==1
export excel Table_4, first(var) replace
