********************************************
* Analysis of Okun's Law
* Contacts: Daniel Leigh and Jair Rodriguez
********************************************

********************************************
* Read in data
********************************************
pause on
set more off
clear
clear matrix
use "$main\data\usa_q_transformed_updated"
*use "Q:\DATA\Okun\other\data_appendix\data\usa_q_transformed_OLD"
cd "$main\outputs"

*gen time = quarterly(quarter, "YQ")
*format time %tq
*drop quarter
*rename time quarter
sort quarter
tsset quarter
sort quarter
save temp, replace

gen lgdp_star16000 = logy - logy_hpf16000  
gen lgdp_star1600  = logy - logy_hpf1600


********************************************
* Regressions
********************************************

*** Sample
keep if quarter <= tq(2013q4)

*** Levels: HPF = 1,600

				
				
matrix table6l = J(3,3,.)
matrix table6u = J(4,9,.)		
				
sureg (u_star1600 lgdp_star1600 l1.lgdp_star1600 l2.lgdp_star1600, noconstant)  (emp1_star1600 lgdp_star1600 l1.lgdp_star1600 l2.lgdp_star1600, noconstant) (u_star1600 emp1_star1600 l1.emp1_star1600 l2.emp1_star1600, noconstant) 
outreg2 using "Table6_AdjR2.xls"  , adjr2    
           erase Table6_AdjR2.txt
				local n = e(N)
				matrix table6l[1,1]=e(N)
				matrix table6l[1,2]=e(N)
				matrix table6l[1,3]=e(N)
				
                local l = `n'^(1/4)
                local l = round(`l')
            
				dwstat
				local dw = r(dw)
				matrix table6l[3,1]=r(dw)
				matrix table6l[3,2]=r(dw)
				matrix table6l[3,3]=r(dw)
				
				local j =1

				
				foreach y in lgdp_star1600 l1.lgdp_star1600 l2.lgdp_star1600{
				local i =1
					foreach x in u_star1600 emp1_star1600 { 
								matrix table6u[`j',`i']=[`x']_b[`y'] 
								local i = `i'+1
								matrix table6u[`j',`i']=[`x']_se[`y'] 
								local i = `i'+1
								test [`x']_b[`y'] =0
								matrix table6u[ `j',`i']=r(p)
									local i = `i'+1
								}
					local j = `j'+1
								}
								local j =1					
				foreach y in emp1_star1600 l1.emp1_star1600 l2.emp1_star1600{
				local i =7
					foreach x in 3u_star1600 {
					display"col `i' row `j'" 
								matrix table6u[`j',`i']=[`x']_b[`y'] 
								local i = `i'+1
								matrix table6u[`j',`i']=[`x']_se[`y'] 
								local i = `i'+1
								test [`x']_b[`y'] =0
								matrix table6u[ `j',`i']=r(p)
									local i = `i'+1
								}
					local j = `j'+1
								}
				
				lincom [u_star1600]_b[lgdp_star1600 ] + [u_star1600]_b[l1.lgdp_star1600] + [u_star1600]_b[l2.lgdp_star1600]
				matrix table6u[4,1] = r(estimate)
				matrix table6u[4,2]= r(se)
				test [u_star1600]_b[lgdp_star1600] + [u_star1600]_b[l1.lgdp_star1600] + [u_star1600]_b[l2.lgdp_star1600] = 0
				matrix table6u[4,3] = r(p)

				lincom [emp1_star1600]_b[lgdp_star1600 ] + [emp1_star1600]_b[l1.lgdp_star1600] + [emp1_star1600]_b[l2.lgdp_star1600]
				matrix table6u[4,4] = r(estimate)
				matrix table6u[4,5]= r(se)
				test [emp1_star1600]_b[lgdp_star1600] + [emp1_star1600]_b[l1.lgdp_star1600] + [emp1_star1600]_b[l2.lgdp_star1600] = 0
				matrix table6u[4,6]= r(p)

				lincom [3u_star1600]_b[emp1_star1600] + [3u_star1600]_b[l1.emp1_star1600] + [3u_star1600]_b[l2.emp1_star1600]
				matrix table6u[4,7] = r(estimate)
				matrix table6u[4,8]= r(se)
				test [3u_star1600]_b[emp1_star1600] + [3u_star1600]_b[l1.emp1_star1600] + [3u_star1600]_b[l2.emp1_star1600] = 0
				matrix table6u[4,9]= r(p)
				

	
mat coln table6l = "U_Y" "E_Y" "U_E" 
mat coln table6u = "C1_b"	"C1_se"	"C1_pv"	"C2_b"	"C2_se"	"C2_pv"	"C3_b"	"C3_se"	"C3_pv"	
matrix rowname table6u = "R1_b0" "R2_b1" "R3_b2" "R4_b0+b1+b2" 
matrix rownames table6l  = "Observations" "Adjusted_R2" "Durbin_Watson"

clear
svmat2 table6l, names(col)  rnames(title)
tostring U_Y E_Y U_E, replace force format (%4.3f)
order title
tempfile stats
save `stats'
clear
svmat2 table6u , names(col)  rnames(title)
forvalues x=1/3{

tostring C`x'_b C`x'_se , replace force format (%4.3f)
replace C`x'_b= C`x'_b + "***" if C`x'_pv<0.01
replace C`x'_b= C`x'_b + "**" if C`x'_pv<0.05 & C`x'_pv>=0.01
replace C`x'_b= C`x'_b + "*" if C`x'_pv<0.1 & C`x'_pv>=0.05
replace C`x'_se = "("+C`x'_se+")" if C`x'_se!="."
drop C`x'_pv
}
reshape long C1 C2 C3 , i(title) j(c) string
local i =1
foreach x in "U_Y" "E_Y" "U_E"{ 
rename C`i' `x'
local i = `i'+1
} 
append using `stats' ,force
drop c

export excel Table_6, first(var) replace







